import numpy as np

def is_prime(n: int) -> bool:
    """
    Check if a given integer is prime. Returns boolean
    Arguments:
    n: int - The number to check
    """
    if n < 1:
        raise ValueError(f"""The argument to is_prime must be a positive
                integer. You supplied {n}.""")
    elif n == 1:
        return False
    elif n == 2:
        return True

    for i in range(2, int(np.ceil(np.sqrt(n))) + 1):
            if n % i == 0:
                return False
    return True



from typing import Callable, Tuple, Any
from functools import partial, wraps
from time import perf_counter

def timeit(function: Callable=None, print_time: bool = True, *args) -> Callable:
    """
    Decorator for measuring the runtime of a function.
    Example usage:
    @timeit
    def my_function(x, y, z):
        return np.sqrt(x ** 2 + y ** 2 + z ** 2)
    the new decorated function will then return its
    result and the runtime in a tuple, i.e.
    my_function(1, 1, 0) --> (1.41..., runtime:float)

    By default, also prints a string
    'Ran in {runtime} seconds', this can be disabled
    by passing print_time=False, for example
    @timeit(print_time=False)
    def my_function(x, y, z):
        ...

    This clever syntax of being able to use the decorator
    by itself or with arguments was heavily inspired (basically
    copy pasted) from this StackOverflow answer:
    https://stackoverflow.com/a/60832711/8304249
    """
    assert callable(function) or function is None
    @wraps(function)
    def _decorator(function):
        def wrapper(*args) -> Tuple[Any, float]:
            start = perf_counter()
            result = function(*args)
            end = perf_counter()
            runtime = end - start
            if print_time:
                print(f'Ran in {end - start} seconds')
            return result, runtime
        return wrapper
    return _decorator(function) if callable(function) else _decorator



from typing import Tuple

def rbg_to_hex(rbg: Tuple[int, int, int]) -> str:
    """
    Convert an rbg tuple to a hex color string.
    For example, (0, 92, 230) -> #005CE6
    Arguments:
    rbg: Tuple[int] - A tuple containing the amount
    of red, green, and blue
    """
    return '#' + ''.join(f'{i:02X}' for i in rbg)

def hex_bgr_to_hex(hex_bgr: str) -> str:
    """
    Converts a hex bgr colors tring (like the ones used
    in .ass files, see https://fileformats.fandom.com/wiki/SubStation_Alpha#Data_types)
    to a regular hex color string. For example
    HE65COO -> #005CE6
    """
    # The initial H character is just to show
    # that the number is hexadecimal
    bgr_hex_colorstring = hex_bgr[1:]
    blue = int(bgr_hex_colorstring[0:2], 16)
    green = int(bgr_hex_colorstring[2:4], 16)
    red = int(bgr_hex_colorstring[4:6], 16)

    rbg = (red, green ,blue)
    return rbg_to_hex(rbg)



#!/usr/bin/env python3
from utils import timeit

@timeit
def main(x: int, y, z) -> int:
    result = x ** 2
    print(f'The answer is {result}')
    return result

if __name__ == '__main__':
    result, runtime = main(1000, 1, 1)
